@@ -34,6 +34,7 @@ class AdbExt(object):
     def __dump_xml(self):
         # 使用 helper 获取 xml
         xml_str = self.run_helper_cmd('layout')
+        xml_str = None
 
         # 使用压缩模式
         if not xml_str:
@@ -43,6 +44,9 @@ class AdbExt(object):
         if not xml_str:
             xml_str = self.util.adb('exec-out uiautomator dump /dev/tty', encoding='')
 
+        if isinstance(xml_str, bytes):
+            xml_str = xml_str.decode('utf-8')
+
         if 'hierarchy' in xml_str:
             start = xml_str.find('<hierarchy')
             end = xml_str.rfind('>') + 1
